FixitDiagnosticsSnapshot class
A point-in-time snapshot of runtime state for diagnostic purposes. Used by the benchmark tool, not for general SDK consumers.
Constructors
Properties
- currentUrl → String?
-
final
-
errors
→ List<
String> -
final
- fps → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool
-
final
- memoryUsage → int
-
final
- progress → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewId → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited